# Automatically created by: scrapyd-deploy
from setuptools import setup, find_packages

setup(
    name             = 'json-pipeline',
    version          = '0.1.1',
    description      = 'Json processing pipeline tools',
    long_description = open('README.md').read(),
    license      = 'BSD',
    author       = 'Martin Olveyra',
    author_email = 'molveyra@gmail.com',
    url = 'https://github.com/kalessin/json-pipeline',
    packages         = find_packages(),
    classifiers = [
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3',
    ],
)
